MethodChannelCamfocus class

An implementation of CamfocusPlatform that uses method channels.

Inheritance

Constructors

MethodChannelCamfocus()

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
The method channel used to interact with the native platform.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() Future<String>
Gets the platform version.
override
initializeCamera() Future<void>
Initializes the camera.
override
isCameraReady() Future<bool>
Checks if the camera is ready for use.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAutoFocus(bool enabled) Future<void>
Sets the auto focus mode.
override
setFocusDistance(double distance) Future<void>
Sets the focus distance.
override
setZoom(double zoomFactor) Future<void>
Sets the zoom factor.
override
takePicture() Future<String>
Takes a picture and returns the file path.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited