CamfocusPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- CamfocusPlatform
- Implementers
Constructors
- CamfocusPlatform()
- Constructs a CamfocusPlatform.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getPlatformVersion(
) → Future< String> - Gets the platform version.
-
initializeCamera(
) → Future< void> - Initializes the camera.
-
isCameraReady(
) → Future< bool> - Checks if the camera is ready for use.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAutoFocus(
bool enabled) → Future< void> - Sets the auto focus mode.
-
setFocusDistance(
double distance) → Future< void> - Sets the focus distance.
-
setZoom(
double zoomFactor) → Future< void> - Sets the zoom factor.
-
takePicture(
) → Future< String> - Takes a picture and returns the file path.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ CamfocusPlatform
-
The default instance of CamfocusPlatform to use.
getter/setter pair